@@ -25,15 +25,15 @@
 #include <string.h>
 #include "gda-bdb.h"
 
-GdaConnectionEvent *
+GdaError *
 gda_bdb_make_error (int ret)
 {
-	GdaConnectionEvent *error = gda_connection_event_new (GDA_CONNECTION_EVENT_ERROR);
+	GdaError *error = gda_error_new ();
 
-	gda_connection_event_set_description (error, db_strerror (ret));
-	gda_connection_event_set_code (error, -1);
-	gda_connection_event_set_source (error, "gda-bdb");
-	gda_connection_event_set_sqlstate (error, _("Not available"));
+	gda_error_set_description (error, db_strerror (ret));
+	gda_error_set_number (error, -1);
+	gda_error_set_source (error, "gda-bdb");
+	gda_error_set_sqlstate (error, _("Not available"));
 	
 	return error;
 }
